//line sql.y:19
package sqlparser

import __yyfmt__ "fmt"

//line sql.y:19
func setParseTree(yylex interface{}, stmt Statement) {
	yylex.(*Tokenizer).ParseTree = stmt
}

func setAllowComments(yylex interface{}, allow bool) {
	yylex.(*Tokenizer).AllowComments = allow
}

func setDDL(yylex interface{}, ddl *DDL) {
	yylex.(*Tokenizer).partialDDL = ddl
}

func incNesting(yylex interface{}) bool {
	yylex.(*Tokenizer).nesting++
	if yylex.(*Tokenizer).nesting == 200 {
		return true
	}
	return false
}

func decNesting(yylex interface{}) {
	yylex.(*Tokenizer).nesting--
}

// forceEOF forces the lexer to end prematurely. Not all SQL statements
// are supported by the Parser, thus calling forceEOF will make the lexer
// return EOF early.
func forceEOF(yylex interface{}) {
	yylex.(*Tokenizer).ForceEOF = true
}

//line sql.y:54
type yySymType struct {
	yys               int
	empty             struct{}
	statement         Statement
	selStmt           SelectStatement
	ddl               *DDL
	ins               *Insert
	byt               byte
	bytes             []byte
	bytes2            [][]byte
	str               string
	strs              []string
	selectExprs       SelectExprs
	selectExpr        SelectExpr
	columns           Columns
	colName           *ColName
	tableExprs        TableExprs
	tableExpr         TableExpr
	joinCondition     JoinCondition
	tableName         TableName
	expr              Expr
	exprs             Exprs
	boolVal           BoolVal
	colTuple          ColTuple
	values            Values
	valTuple          ValTuple
	subquery          *Subquery
	whens             []*When
	when              *When
	orderBy           OrderBy
	order             *Order
	limit             *Limit
	updateExprs       UpdateExprs
	setExprs          SetExprs
	updateExpr        *UpdateExpr
	setExpr           *SetExpr
	colIdent          ColIdent
	tableIdent        TableIdent
	convertType       *ConvertType
	aliasedTableName  *AliasedTableExpr
	TableSpec         *TableSpec
	columnType        ColumnType
	colKeyOpt         ColumnKeyOption
	optVal            *SQLVal
	LengthScaleOption LengthScaleOption
	columnDefinition  *ColumnDefinition
	indexDefinition   *IndexDefinition
	indexInfo         *IndexInfo
	indexColumn       *IndexColumn
	indexColumns      []*IndexColumn
}

const LEX_ERROR = 57346
const UNION = 57347
const SELECT = 57348
const INSERT = 57349
const UPDATE = 57350
const DELETE = 57351
const FROM = 57352
const WHERE = 57353
const GROUP = 57354
const HAVING = 57355
const ORDER = 57356
const BY = 57357
const LIMIT = 57358
const OFFSET = 57359
const ALL = 57360
const DISTINCT = 57361
const AS = 57362
const EXISTS = 57363
const ASC = 57364
const DESC = 57365
const INTO = 57366
const KEY = 57367
const DEFAULT = 57368
const SET = 57369
const VALUES = 57370
const LAST_INSERT_ID = 57371
const JOIN = 57372
const LEFT = 57373
const RIGHT = 57374
const INNER = 57375
const OUTER = 57376
const CROSS = 57377
const NATURAL = 57378
const ON = 57379
const USING = 57380
const ID = 57381
const HEX = 57382
const STRING = 57383
const INTEGRAL = 57384
const FLOAT = 57385
const HEXNUM = 57386
const VALUE_ARG = 57387
const LIST_ARG = 57388
const COMMENT = 57389
const NULL = 57390
const TRUE = 57391
const FALSE = 57392
const FULL = 57393
const COLUMNS = 57394
const OR = 57395
const AND = 57396
const NOT = 57397
const BETWEEN = 57398
const CASE = 57399
const WHEN = 57400
const THEN = 57401
const ELSE = 57402
const END = 57403
const LE = 57404
const GE = 57405
const NE = 57406
const IS = 57407
const LIKE = 57408
const REGEXP = 57409
const IN = 57410
const NULL_SAFE_NOTEQUAL = 57411
const SHIFT_LEFT = 57412
const SHIFT_RIGHT = 57413
const DIV = 57414
const MOD = 57415
const UNARY = 57416
const INTERVAL = 57417
const CREATE = 57418
const ALTER = 57419
const DROP = 57420
const RENAME = 57421
const ADD = 57422
const TABLE = 57423
const INDEX = 57424
const TO = 57425
const IGNORE = 57426
const IF = 57427
const UNIQUE = 57428
const PRIMARY = 57429
const COLUMN = 57430
const CONSTRAINT = 57431
const FOREIGN = 57432
const SHOW = 57433
const DESCRIBE = 57434
const DATE = 57435
const ESCAPE = 57436
const TINYINT = 57437
const SMALLINT = 57438
const MEDIUMINT = 57439
const INT = 57440
const INTEGER = 57441
const BIGINT = 57442
const INTNUM = 57443
const REAL = 57444
const DOUBLE = 57445
const FLOAT_TYPE = 57446
const DECIMAL = 57447
const NUMERIC = 57448
const TIME = 57449
const TIMESTAMP = 57450
const DATETIME = 57451
const YEAR = 57452
const CHAR = 57453
const VARCHAR = 57454
const BOOL = 57455
const NCHAR = 57456
const TEXT = 57457
const TINYTEXT = 57458
const MEDIUMTEXT = 57459
const LONGTEXT = 57460
const BLOB = 57461
const TINYBLOB = 57462
const MEDIUMBLOB = 57463
const LONGBLOB = 57464
const AUTO_INCREMENT = 57465
const SIGNED = 57466
const UNSIGNED = 57467
const ZEROFILL = 57468
const TABLES = 57469
const CURRENT_TIMESTAMP = 57470
const CURRENT_DATE = 57471
const CURRENT_TIME = 57472
const REPLACE = 57473
const CAST = 57474
const SUBSTR = 57475
const GROUP_CONCAT = 57476
const SEPARATOR = 57477
const UNUSED = 57478

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"LEX_ERROR",
	"UNION",
	"SELECT",
	"INSERT",
	"UPDATE",
	"DELETE",
	"FROM",
	"WHERE",
	"GROUP",
	"HAVING",
	"ORDER",
	"BY",
	"LIMIT",
	"OFFSET",
	"ALL",
	"DISTINCT",
	"AS",
	"EXISTS",
	"ASC",
	"DESC",
	"INTO",
	"KEY",
	"DEFAULT",
	"SET",
	"VALUES",
	"LAST_INSERT_ID",
	"JOIN",
	"LEFT",
	"RIGHT",
	"INNER",
	"OUTER",
	"CROSS",
	"NATURAL",
	"ON",
	"USING",
	"'('",
	"','",
	"')'",
	"ID",
	"HEX",
	"STRING",
	"INTEGRAL",
	"FLOAT",
	"HEXNUM",
	"VALUE_ARG",
	"LIST_ARG",
	"COMMENT",
	"NULL",
	"TRUE",
	"FALSE",
	"FULL",
	"COLUMNS",
	"OR",
	"AND",
	"NOT",
	"'!'",
	"BETWEEN",
	"CASE",
	"WHEN",
	"THEN",
	"ELSE",
	"END",
	"'='",
	"'<'",
	"'>'",
	"LE",
	"GE",
	"NE",
	"IS",
	"LIKE",
	"REGEXP",
	"IN",
	"NULL_SAFE_NOTEQUAL",
	"'|'",
	"'&'",
	"SHIFT_LEFT",
	"SHIFT_RIGHT",
	"'+'",
	"'-'",
	"'*'",
	"'/'",
	"DIV",
	"'%'",
	"MOD",
	"'^'",
	"'~'",
	"UNARY",
	"INTERVAL",
	"'.'",
	"CREATE",
	"ALTER",
	"DROP",
	"RENAME",
	"ADD",
	"TABLE",
	"INDEX",
	"TO",
	"IGNORE",
	"IF",
	"UNIQUE",
	"PRIMARY",
	"COLUMN",
	"CONSTRAINT",
	"FOREIGN",
	"SHOW",
	"DESCRIBE",
	"DATE",
	"ESCAPE",
	"TINYINT",
	"SMALLINT",
	"MEDIUMINT",
	"INT",
	"INTEGER",
	"BIGINT",
	"INTNUM",
	"REAL",
	"DOUBLE",
	"FLOAT_TYPE",
	"DECIMAL",
	"NUMERIC",
	"TIME",
	"TIMESTAMP",
	"DATETIME",
	"YEAR",
	"CHAR",
	"VARCHAR",
	"BOOL",
	"NCHAR",
	"TEXT",
	"TINYTEXT",
	"MEDIUMTEXT",
	"LONGTEXT",
	"BLOB",
	"TINYBLOB",
	"MEDIUMBLOB",
	"LONGBLOB",
	"AUTO_INCREMENT",
	"SIGNED",
	"UNSIGNED",
	"ZEROFILL",
	"TABLES",
	"CURRENT_TIMESTAMP",
	"CURRENT_DATE",
	"CURRENT_TIME",
	"REPLACE",
	"CAST",
	"SUBSTR",
	"GROUP_CONCAT",
	"SEPARATOR",
	"UNUSED",
	"';'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 3,
	5, 17,
	-2, 4,
	-1, 114,
	1, 156,
	5, 156,
	11, 156,
	12, 156,
	13, 156,
	14, 156,
	16, 156,
	27, 156,
	30, 156,
	31, 156,
	33, 156,
	35, 156,
	36, 156,
	37, 156,
	38, 156,
	40, 156,
	41, 156,
	154, 156,
	-2, 169,
	-1, 183,
	92, 356,
	-2, 352,
	-1, 184,
	92, 357,
	-2, 353,
	-1, 402,
	5, 17,
	-2, 325,
	-1, 519,
	92, 359,
	-2, 355,
	-1, 551,
	5, 18,
	-2, 228,
	-1, 609,
	5, 18,
	-2, 326,
	-1, 672,
	5, 17,
	-2, 328,
	-1, 732,
	5, 18,
	-2, 329,
}

const yyPrivate = 57344

const yyLast = 4079

var yyAct = [...]int{

	184, 381, 623, 136, 534, 429, 459, 514, 337, 535,
	142, 99, 31, 587, 428, 434, 207, 3, 406, 46,
	168, 526, 518, 94, 94, 489, 474, 147, 170, 440,
	405, 206, 119, 464, 546, 430, 335, 455, 94, 44,
	425, 210, 97, 186, 197, 134, 30, 111, 715, 138,
	132, 516, 566, 116, 110, 447, 627, 628, 629, 630,
	705, 122, 703, 466, 631, 684, 465, 123, 465, 109,
	126, 107, 638, 442, 84, 85, 91, 95, 121, 258,
	253, 252, 719, 128, 94, 83, 641, 353, 90, 94,
	560, 352, 351, 361, 362, 354, 355, 356, 357, 358,
	359, 360, 353, 612, 594, 125, 667, 94, 544, 139,
	187, 478, 380, 133, 341, 188, 94, 94, 94, 171,
	25, 189, 543, 94, 527, 588, 94, 86, 94, 94,
	340, 339, 88, 87, 94, 251, 339, 124, 527, 131,
	601, 444, 130, 685, 683, 25, 341, 441, 445, 262,
	344, 341, 448, 104, 496, 442, 260, 115, 632, 98,
	192, 374, 375, 376, 377, 378, 564, 494, 495, 493,
	193, 214, 120, 580, 581, 582, 250, 687, 686, 254,
	382, 256, 257, 249, 388, 569, 334, 24, 26, 15,
	16, 127, 94, 398, 568, 596, 94, 94, 94, 94,
	397, 340, 339, 28, 22, 94, 567, 402, 669, 94,
	421, 422, 94, 492, 731, 408, 46, 341, 720, 721,
	28, 625, 407, 137, 25, 423, 726, 395, 396, 441,
	120, 340, 339, 439, 438, 208, 433, 356, 357, 358,
	359, 360, 353, 561, 411, 404, 413, 341, 419, 435,
	410, 512, 412, 424, 462, 461, 680, 679, 725, 94,
	94, 340, 339, 371, 373, 354, 355, 356, 357, 358,
	359, 360, 353, 633, 18, 19, 20, 341, 471, 137,
	343, 636, 635, 457, 458, 611, 137, 467, 379, 21,
	23, 383, 384, 385, 386, 520, 389, 482, 484, 485,
	390, 391, 392, 342, 483, 520, 137, 195, 137, 607,
	403, 195, 468, 469, 32, 115, 115, 115, 115, 340,
	339, 216, 215, 472, 24, 426, 634, 542, 208, 27,
	597, 471, 554, 393, 194, 341, 199, 202, 46, 200,
	471, 201, 203, 547, 548, 400, 401, 195, 479, 480,
	24, 486, 487, 471, 542, 28, 488, 28, 476, 497,
	498, 499, 500, 501, 502, 503, 504, 505, 506, 507,
	508, 509, 510, 511, 449, 490, 450, 451, 460, 46,
	618, 24, 557, 28, 664, 521, 456, 452, 453, 454,
	547, 548, 382, 522, 40, 570, 519, 418, 202, 513,
	423, 433, 187, 671, 46, 12, 408, 416, 550, 415,
	408, 417, 414, 523, 28, 563, 517, 528, 724, 723,
	538, 408, 558, 463, 540, 255, 205, 551, 407, 46,
	536, 533, 524, 135, 555, 553, 105, 532, 552, 103,
	100, 694, 529, 530, 531, 101, 541, 549, 32, 433,
	651, 693, 660, 661, 662, 659, 426, 663, 640, 259,
	129, 117, 653, 34, 656, 658, 652, 94, 650, 559,
	36, 654, 29, 94, 199, 202, 46, 200, 1, 201,
	203, 655, 657, 89, 622, 437, 427, 118, 408, 39,
	149, 436, 682, 25, 519, 573, 476, 571, 626, 433,
	443, 579, 577, 383, 576, 584, 585, 586, 575, 565,
	446, 574, 562, 219, 517, 220, 590, 218, 591, 583,
	572, 537, 490, 25, 222, 221, 217, 649, 114, 595,
	688, 204, 603, 604, 605, 606, 602, 209, 473, 41,
	370, 608, 609, 610, 106, 677, 382, 600, 539, 394,
	185, 692, 615, 639, 613, 46, 617, 46, 46, 599,
	519, 614, 621, 408, 619, 433, 387, 592, 525, 620,
	407, 94, 148, 481, 158, 433, 598, 433, 624, 155,
	616, 351, 361, 362, 354, 355, 356, 357, 358, 359,
	360, 353, 115, 157, 156, 46, 646, 145, 642, 644,
	645, 647, 399, 345, 146, 140, 114, 113, 665, 190,
	668, 666, 46, 46, 198, 433, 196, 670, 545, 46,
	112, 46, 470, 714, 637, 676, 555, 672, 14, 33,
	648, 108, 674, 675, 11, 372, 536, 593, 46, 678,
	35, 433, 46, 10, 17, 9, 8, 169, 7, 6,
	5, 697, 4, 698, 696, 102, 37, 38, 433, 408,
	701, 13, 433, 2, 0, 96, 691, 713, 137, 712,
	92, 92, 0, 690, 0, 0, 717, 648, 716, 0,
	0, 46, 0, 722, 0, 92, 114, 114, 114, 114,
	718, 0, 0, 0, 0, 0, 728, 0, 0, 114,
	536, 624, 727, 382, 352, 351, 361, 362, 354, 355,
	356, 357, 358, 359, 360, 353, 0, 0, 730, 0,
	46, 46, 732, 0, 729, 0, 0, 537, 0, 0,
	673, 92, 0, 735, 0, 0, 92, 0, 0, 0,
	733, 734, 352, 351, 361, 362, 354, 355, 356, 357,
	358, 359, 360, 353, 92, 0, 0, 689, 0, 0,
	0, 0, 0, 92, 212, 92, 0, 0, 0, 0,
	92, 0, 0, 92, 0, 92, 92, 681, 0, 0,
	0, 261, 338, 137, 0, 0, 0, 0, 0, 0,
	0, 537, 0, 25, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 699, 0, 700, 0, 702, 0, 704,
	0, 706, 707, 708, 709, 710, 711, 0, 0, 352,
	351, 361, 362, 354, 355, 356, 357, 358, 359, 360,
	353, 0, 0, 0, 0, 0, 0, 491, 0, 92,
	643, 0, 409, 92, 92, 92, 92, 0, 0, 0,
	0, 0, 420, 0, 0, 0, 92, 0, 0, 212,
	352, 351, 361, 362, 354, 355, 356, 357, 358, 359,
	360, 353, 361, 362, 354, 355, 356, 357, 358, 359,
	360, 353, 0, 67, 0, 515, 0, 144, 0, 0,
	0, 0, 143, 0, 176, 59, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 28, 92, 92, 183, 160,
	159, 161, 162, 163, 164, 589, 0, 165, 166, 167,
	0, 0, 0, 0, 141, 153, 0, 175, 0, 0,
	0, 0, 0, 0, 0, 352, 351, 361, 362, 354,
	355, 356, 357, 358, 359, 360, 353, 150, 151, 336,
	0, 0, 0, 181, 0, 152, 0, 154, 0, 0,
	0, 0, 0, 114, 0, 0, 0, 0, 180, 0,
	68, 0, 0, 56, 0, 0, 51, 0, 76, 71,
	63, 57, 58, 47, 491, 69, 54, 55, 53, 66,
	73, 74, 52, 81, 50, 80, 49, 65, 72, 77,
	64, 61, 48, 75, 62, 60, 0, 70, 78, 82,
	0, 177, 178, 179, 182, 172, 173, 174, 0, 79,
	0, 0, 0, 0, 0, 0, 0, 338, 261, 0,
	0, 0, 0, 409, 67, 0, 0, 409, 338, 338,
	338, 0, 0, 0, 0, 0, 59, 0, 409, 0,
	0, 233, 0, 238, 239, 240, 241, 242, 243, 45,
	244, 245, 246, 247, 248, 234, 235, 236, 237, 223,
	224, 0, 0, 225, 226, 227, 228, 229, 230, 231,
	232, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 352, 351, 361, 362, 354, 355,
	356, 357, 358, 359, 360, 353, 0, 0, 0, 0,
	0, 0, 0, 0, 92, 409, 0, 0, 0, 338,
	92, 68, 0, 0, 56, 0, 261, 51, 0, 76,
	71, 63, 57, 58, 47, 0, 69, 54, 55, 53,
	66, 73, 74, 52, 81, 50, 80, 49, 65, 72,
	77, 64, 61, 48, 75, 62, 60, 0, 70, 78,
	82, 0, 0, 338, 0, 0, 0, 0, 0, 0,
	79, 0, 338, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	409, 0, 261, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 327, 318, 297, 329, 278,
	289, 333, 290, 291, 312, 269, 305, 67, 92, 281,
	265, 287, 266, 279, 299, 302, 277, 320, 331, 59,
	301, 303, 317, 296, 313, 272, 307, 310, 330, 0,
	0, 338, 45, 0, 431, 432, 0, 0, 0, 0,
	0, 309, 326, 288, 0, 0, 311, 264, 308, 0,
	268, 270, 332, 324, 284, 285, 556, 0, 0, 0,
	0, 0, 300, 304, 314, 294, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 282, 409, 306, 0, 0,
	0, 298, 0, 271, 0, 283, 315, 263, 322, 295,
	325, 293, 292, 328, 68, 0, 0, 56, 321, 280,
	51, 286, 76, 71, 63, 57, 58, 47, 0, 69,
	54, 55, 53, 66, 73, 74, 52, 81, 50, 80,
	49, 65, 72, 77, 64, 61, 48, 75, 62, 60,
	267, 70, 78, 82, 323, 275, 273, 274, 316, 0,
	276, 0, 319, 79, 327, 318, 297, 329, 278, 289,
	333, 290, 291, 312, 269, 305, 67, 0, 281, 265,
	287, 266, 279, 299, 302, 277, 320, 331, 59, 301,
	303, 317, 296, 313, 272, 307, 310, 330, 0, 0,
	0, 45, 0, 431, 432, 0, 0, 0, 0, 0,
	309, 326, 288, 0, 0, 311, 264, 308, 0, 268,
	270, 332, 324, 284, 285, 0, 0, 0, 0, 0,
	0, 300, 304, 314, 294, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 282, 0, 306, 0, 0, 0,
	298, 0, 271, 0, 283, 315, 263, 322, 295, 325,
	293, 292, 328, 68, 0, 0, 56, 321, 280, 51,
	286, 76, 71, 63, 57, 58, 47, 0, 69, 54,
	55, 53, 66, 73, 74, 52, 81, 50, 80, 49,
	65, 72, 77, 64, 61, 48, 75, 62, 60, 267,
	70, 78, 82, 323, 275, 273, 274, 316, 0, 276,
	0, 319, 79, 327, 318, 297, 329, 278, 289, 333,
	290, 291, 312, 269, 305, 67, 0, 281, 265, 287,
	266, 279, 299, 302, 277, 320, 331, 59, 301, 303,
	317, 296, 313, 272, 307, 310, 330, 0, 0, 0,
	45, 0, 0, 0, 0, 0, 0, 0, 0, 309,
	326, 288, 0, 0, 311, 264, 308, 0, 268, 270,
	332, 324, 284, 285, 0, 0, 0, 0, 0, 0,
	300, 304, 314, 294, 0, 0, 0, 0, 0, 0,
	0, 695, 0, 282, 0, 306, 0, 0, 0, 298,
	0, 271, 0, 283, 315, 263, 322, 295, 325, 293,
	292, 328, 68, 0, 0, 56, 321, 280, 51, 286,
	76, 71, 63, 57, 58, 47, 0, 69, 54, 55,
	53, 66, 73, 74, 52, 81, 50, 80, 49, 65,
	72, 77, 64, 61, 48, 75, 62, 60, 267, 70,
	78, 82, 323, 275, 273, 274, 316, 0, 276, 0,
	319, 79, 327, 318, 297, 329, 278, 289, 333, 290,
	291, 312, 269, 305, 67, 0, 281, 265, 287, 266,
	279, 299, 302, 277, 320, 331, 59, 301, 303, 317,
	296, 313, 272, 307, 310, 330, 28, 0, 0, 45,
	0, 0, 0, 0, 0, 0, 0, 0, 309, 326,
	288, 0, 0, 311, 264, 308, 0, 268, 270, 332,
	324, 284, 285, 0, 0, 0, 0, 0, 0, 300,
	304, 314, 294, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 282, 0, 306, 0, 0, 0, 298, 0,
	271, 0, 283, 315, 263, 322, 295, 325, 293, 292,
	328, 68, 0, 0, 56, 321, 280, 51, 286, 76,
	71, 63, 57, 58, 47, 0, 69, 54, 55, 53,
	66, 73, 74, 52, 81, 50, 80, 49, 65, 72,
	77, 64, 61, 48, 75, 62, 60, 267, 70, 78,
	82, 323, 275, 273, 274, 316, 0, 276, 0, 319,
	79, 327, 318, 297, 329, 278, 289, 333, 290, 291,
	312, 269, 305, 67, 0, 281, 265, 287, 266, 279,
	299, 302, 277, 320, 331, 59, 301, 303, 317, 296,
	313, 272, 307, 310, 330, 0, 0, 0, 183, 0,
	0, 0, 0, 0, 0, 0, 0, 309, 326, 288,
	0, 0, 311, 264, 308, 0, 268, 270, 332, 324,
	284, 285, 0, 0, 0, 0, 0, 0, 300, 304,
	314, 294, 0, 0, 0, 0, 0, 0, 0, 578,
	0, 282, 0, 306, 0, 0, 0, 298, 0, 271,
	0, 283, 315, 263, 322, 295, 325, 293, 292, 328,
	68, 0, 0, 56, 321, 280, 51, 286, 76, 71,
	63, 57, 58, 47, 0, 69, 54, 55, 53, 66,
	73, 74, 52, 81, 50, 80, 49, 65, 72, 77,
	64, 61, 48, 75, 62, 60, 267, 70, 78, 82,
	323, 275, 273, 274, 316, 0, 276, 0, 319, 79,
	327, 318, 297, 329, 278, 289, 333, 290, 291, 312,
	269, 305, 67, 0, 281, 265, 287, 266, 279, 299,
	302, 277, 320, 331, 59, 301, 303, 317, 296, 313,
	272, 307, 310, 330, 0, 0, 0, 45, 0, 0,
	0, 0, 0, 0, 0, 0, 309, 326, 288, 0,
	0, 311, 264, 308, 0, 268, 270, 332, 324, 284,
	285, 0, 0, 0, 0, 0, 0, 300, 304, 314,
	294, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	282, 0, 306, 0, 0, 0, 298, 0, 271, 0,
	283, 315, 263, 322, 295, 325, 293, 292, 328, 68,
	0, 0, 56, 321, 280, 51, 286, 76, 71, 63,
	57, 58, 47, 0, 69, 54, 55, 53, 66, 73,
	74, 52, 81, 50, 80, 49, 65, 72, 77, 64,
	61, 48, 75, 62, 60, 267, 70, 78, 82, 323,
	275, 273, 274, 316, 0, 276, 0, 319, 79, 327,
	318, 297, 329, 278, 289, 333, 290, 291, 312, 269,
	305, 67, 0, 281, 265, 287, 266, 279, 299, 302,
	277, 320, 331, 59, 301, 303, 317, 296, 313, 272,
	307, 310, 330, 0, 0, 0, 183, 0, 0, 0,
	0, 0, 0, 0, 0, 309, 326, 288, 0, 0,
	311, 264, 308, 0, 268, 270, 332, 324, 284, 285,
	0, 0, 0, 0, 0, 0, 300, 304, 314, 294,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 282,
	0, 306, 0, 0, 0, 298, 0, 271, 0, 283,
	315, 263, 322, 295, 325, 293, 292, 328, 68, 0,
	0, 56, 321, 280, 51, 286, 76, 71, 63, 57,
	58, 47, 0, 69, 54, 55, 53, 66, 73, 74,
	52, 81, 50, 80, 49, 65, 72, 77, 64, 61,
	48, 75, 62, 60, 267, 70, 78, 82, 323, 275,
	273, 274, 316, 0, 276, 0, 319, 79, 327, 318,
	297, 329, 278, 289, 333, 290, 291, 312, 269, 305,
	67, 0, 281, 265, 287, 266, 279, 299, 302, 277,
	320, 331, 59, 301, 303, 317, 296, 313, 272, 307,
	310, 330, 0, 0, 0, 93, 0, 0, 0, 0,
	0, 0, 0, 0, 309, 326, 288, 0, 0, 311,
	264, 308, 0, 268, 270, 332, 324, 284, 285, 0,
	0, 0, 0, 0, 0, 300, 304, 314, 294, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 282, 0,
	306, 0, 0, 0, 298, 0, 271, 0, 283, 315,
	263, 322, 295, 325, 293, 292, 328, 68, 0, 0,
	56, 321, 280, 51, 286, 76, 71, 63, 57, 58,
	47, 0, 69, 54, 55, 53, 66, 73, 74, 52,
	81, 50, 80, 49, 65, 72, 77, 64, 61, 48,
	75, 62, 60, 267, 70, 78, 82, 323, 275, 273,
	274, 316, 0, 276, 67, 319, 79, 0, 144, 0,
	0, 0, 0, 143, 0, 176, 59, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 28, 0, 0, 183,
	160, 159, 161, 162, 163, 164, 0, 0, 165, 166,
	167, 0, 0, 0, 0, 141, 153, 0, 175, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 150, 151,
	336, 0, 0, 0, 181, 0, 152, 0, 154, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 180,
	0, 68, 0, 0, 56, 0, 0, 51, 0, 76,
	71, 63, 57, 58, 47, 0, 69, 54, 55, 53,
	66, 73, 74, 52, 81, 50, 80, 49, 65, 72,
	77, 64, 61, 48, 75, 62, 60, 0, 70, 78,
	82, 0, 177, 178, 179, 182, 172, 173, 174, 67,
	79, 0, 0, 144, 0, 0, 0, 0, 143, 0,
	176, 59, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 28, 0, 137, 183, 160, 159, 161, 162, 163,
	164, 0, 0, 165, 166, 167, 0, 0, 0, 0,
	141, 153, 0, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 150, 151, 0, 0, 0, 0, 181,
	0, 152, 0, 154, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 180, 0, 68, 0, 0, 56,
	0, 0, 51, 0, 76, 71, 63, 57, 58, 47,
	0, 69, 54, 55, 53, 66, 73, 74, 52, 81,
	50, 80, 49, 65, 72, 77, 64, 61, 48, 75,
	62, 60, 0, 70, 78, 82, 24, 177, 178, 179,
	182, 172, 173, 174, 0, 79, 0, 67, 0, 0,
	0, 144, 0, 0, 0, 0, 143, 0, 176, 59,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 28,
	0, 0, 183, 160, 159, 161, 162, 163, 164, 0,
	0, 165, 166, 167, 0, 0, 0, 0, 141, 153,
	0, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 150, 151, 0, 0, 0, 0, 181, 0, 152,
	0, 154, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 180, 0, 68, 0, 0, 56, 0, 0,
	51, 0, 76, 71, 63, 57, 58, 47, 0, 69,
	54, 55, 53, 66, 73, 74, 52, 81, 50, 80,
	49, 65, 72, 77, 64, 61, 48, 75, 62, 60,
	0, 70, 78, 82, 0, 177, 178, 179, 182, 172,
	173, 174, 67, 79, 0, 0, 144, 0, 0, 0,
	0, 143, 0, 176, 59, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 28, 0, 0, 183, 160, 159,
	161, 162, 163, 164, 0, 0, 165, 166, 167, 0,
	0, 0, 0, 141, 153, 0, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 150, 151, 0, 0,
	0, 0, 181, 0, 152, 0, 154, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 180, 0, 68,
	0, 0, 56, 0, 0, 51, 0, 76, 71, 63,
	57, 58, 47, 0, 69, 54, 55, 53, 66, 73,
	74, 52, 81, 50, 80, 49, 65, 72, 77, 64,
	61, 48, 75, 62, 60, 0, 70, 78, 82, 67,
	177, 178, 179, 182, 172, 173, 174, 0, 79, 0,
	176, 59, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 28, 0, 0, 183, 160, 159, 161, 162, 163,
	164, 0, 0, 165, 166, 167, 0, 0, 0, 0,
	0, 153, 0, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 150, 151, 0, 0, 0, 0, 181,
	0, 152, 0, 154, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 180, 0, 68, 0, 0, 56,
	0, 0, 51, 0, 76, 71, 63, 57, 58, 47,
	0, 69, 54, 55, 53, 66, 73, 74, 52, 81,
	50, 80, 49, 65, 72, 77, 64, 61, 48, 75,
	62, 60, 0, 70, 78, 82, 0, 177, 178, 179,
	182, 172, 173, 174, 67, 79, 0, 475, 0, 0,
	0, 0, 0, 0, 0, 0, 59, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	0, 477, 0, 0, 0, 24, 0, 0, 0, 0,
	0, 0, 0, 340, 339, 0, 67, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 59, 341,
	0, 0, 0, 0, 0, 0, 0, 0, 28, 0,
	0, 45, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 68, 0, 0, 56, 0, 0, 51, 0, 76,
	71, 63, 57, 58, 47, 0, 69, 54, 55, 53,
	66, 73, 74, 52, 81, 50, 80, 49, 65, 72,
	77, 64, 61, 48, 75, 62, 60, 0, 70, 78,
	82, 0, 0, 68, 0, 0, 56, 0, 0, 51,
	79, 76, 71, 63, 57, 58, 47, 0, 69, 54,
	55, 53, 66, 73, 74, 52, 81, 50, 80, 49,
	65, 72, 77, 64, 61, 48, 75, 62, 60, 24,
	70, 78, 82, 0, 0, 0, 0, 0, 0, 0,
	67, 0, 79, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 59, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 28, 0, 0, 93, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 67, 0, 0, 211, 0, 0, 0, 0,
	0, 0, 0, 0, 59, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 93, 0, 213,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 68, 0, 0,
	56, 0, 0, 51, 0, 76, 71, 63, 57, 58,
	47, 0, 69, 54, 55, 53, 66, 73, 74, 52,
	81, 50, 80, 49, 65, 72, 77, 64, 61, 48,
	75, 62, 60, 0, 70, 78, 82, 0, 0, 68,
	0, 0, 56, 0, 0, 51, 79, 76, 71, 63,
	57, 58, 47, 0, 69, 54, 55, 53, 66, 73,
	74, 52, 81, 50, 80, 49, 65, 72, 77, 64,
	61, 48, 75, 62, 60, 67, 70, 78, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 59, 79, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	45, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 59,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 0, 477, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 42, 0, 0, 0,
	0, 43, 68, 0, 0, 56, 0, 0, 51, 0,
	76, 71, 63, 57, 58, 47, 0, 69, 54, 55,
	53, 66, 73, 74, 52, 81, 50, 80, 49, 65,
	72, 77, 64, 61, 48, 75, 62, 60, 0, 70,
	78, 82, 0, 0, 68, 0, 0, 56, 0, 0,
	51, 79, 76, 71, 63, 57, 58, 47, 0, 69,
	54, 55, 53, 66, 73, 74, 52, 81, 50, 80,
	49, 65, 72, 77, 64, 61, 48, 75, 62, 60,
	67, 70, 78, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 59, 79, 0, 0, 0, 0, 0, 0,
	0, 0, 28, 0, 0, 93, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 59, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 93, 0, 213,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 68, 0, 0,
	56, 0, 0, 51, 0, 76, 71, 63, 57, 58,
	47, 0, 69, 54, 55, 53, 66, 73, 74, 52,
	81, 50, 80, 49, 65, 72, 77, 64, 61, 48,
	75, 62, 60, 0, 70, 78, 82, 0, 0, 68,
	0, 0, 56, 0, 0, 51, 79, 76, 71, 63,
	57, 58, 47, 0, 69, 54, 55, 53, 66, 73,
	74, 52, 81, 50, 80, 49, 65, 72, 77, 64,
	61, 48, 75, 62, 60, 67, 70, 78, 82, 0,
	0, 0, 191, 0, 0, 0, 0, 59, 79, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	93, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 67, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 347, 59,
	350, 0, 0, 0, 0, 0, 363, 364, 365, 366,
	367, 368, 45, 348, 349, 346, 369, 352, 351, 361,
	362, 354, 355, 356, 357, 358, 359, 360, 353, 0,
	0, 0, 68, 0, 0, 56, 0, 0, 51, 0,
	76, 71, 63, 57, 58, 47, 0, 69, 54, 55,
	53, 66, 73, 74, 52, 81, 50, 80, 49, 65,
	72, 77, 64, 61, 48, 75, 62, 60, 0, 70,
	78, 82, 0, 0, 68, 0, 0, 56, 0, 0,
	51, 79, 76, 71, 63, 57, 58, 47, 0, 69,
	54, 55, 53, 66, 73, 74, 52, 81, 50, 80,
	49, 65, 72, 77, 64, 61, 48, 75, 62, 60,
	67, 70, 78, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 59, 79, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 183, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 67, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 59, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 68, 0, 0,
	56, 0, 0, 51, 0, 76, 71, 63, 57, 58,
	47, 0, 69, 54, 55, 53, 66, 73, 74, 52,
	81, 50, 80, 49, 65, 72, 77, 64, 61, 48,
	75, 62, 60, 0, 70, 78, 82, 0, 0, 68,
	0, 0, 56, 0, 0, 51, 79, 76, 71, 63,
	57, 58, 47, 0, 69, 54, 55, 53, 66, 73,
	74, 52, 81, 50, 80, 49, 65, 72, 77, 64,
	61, 48, 75, 62, 60, 0, 70, 78, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 79,
}
var yyPact = [...]int{

	181, -1000, -108, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 434, 458, -1000, -1000, -1000, 355, 3388, -13,
	-24, 34, 3925, 3925, -1000, 344, 103, -1000, -1000, -1000,
	-1000, 424, 430, 344, 418, -30, -1000, 3553, 451, -1000,
	188, -21, -35, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 3925, -32, -32, -15, 450, 3925, -5,
	-1000, -1000, 21, -1000, -1000, -1000, 414, 182, -99, -1000,
	2785, 2785, 434, -1000, 344, -1000, 3718, -1000, 120, 307,
	444, -1000, -1000, -1000, 406, 3223, 3265, 3925, 281, -1000,
	941, -35, 3925, 77, -16, 3925, 404, 3925, 3925, -19,
	-1000, -1000, 449, 2243, 2377, -1000, -1000, -1000, -1000, 263,
	-1000, 2785, 3730, 316, 316, -1000, -1000, -1000, -1000, -1000,
	2912, 2912, 2912, 2912, 2912, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 316, 20,
	-1000, 2650, 316, 316, 316, 2785, 316, -1000, -1000, -1000,
	316, 316, 316, -1000, -1000, 293, -1000, 205, 424, 182,
	318, 3925, -1000, -1000, 3883, 3553, 3553, 3553, 3553, -1000,
	382, 379, 377, 367, 3925, -1000, 267, 182, 3223, -1000,
	-1000, 3595, -1000, -1000, 445, 1349, 130, 90, -87, -1000,
	-1000, 335, -1000, 335, 335, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 335, 335, 335, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 347, 347, 347, 339, 339, 212,
	-1000, 402, -39, -37, -1000, -1000, -1000, -1000, 3925, 3925,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 313, -1000, -1000, 3047, 19, 2785,
	2785, 246, 2785, 2785, 42, 2912, 164, 94, 2912, 2912,
	2912, 2912, 2912, 2912, 2912, 2912, 2912, 2912, 2912, 2912,
	2912, 2912, 2912, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, 209, -1000, 344, -1000, -1000, -1000, -1000, 1017, 866,
	2094, 265, 74, 2650, 2785, 3883, 414, 62, 74, 3883,
	2377, 2377, 2377, 2785, -1000, -1000, -1000, -1000, -1000, -1000,
	3883, 316, -1000, 3089, -1000, 314, -1000, 56, -1000, 16,
	444, 353, 306, -1000, -1000, -1000, -1000, 378, -1000, -1000,
	-1000, -1000, -1000, 182, -1000, 434, 2785, 292, 1200, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, 343, 397, 48,
	201, -1000, -1000, 389, -1000, 115, -91, -1000, -1000, 161,
	-1000, -1000, -1000, -1000, -1000, -1000, 149, -1000, -1000, -1000,
	140, -1000, 358, -1000, 188, -1000, 3925, 3883, -1000, -1000,
	445, 2377, 3553, -1000, -1000, 3430, -1000, -1000, 1796, 42,
	79, -1000, -1000, 122, -1000, -1000, 74, 74, 665, -1000,
	-1000, -1000, -1000, 164, 2912, 2912, 2912, 14, 665, 858,
	793, 503, -1000, 154, 154, -1, -1, -1, -1, -1,
	184, 184, 182, -1000, 182, 2377, 291, 316, 12, -1000,
	2785, -1000, 175, 290, 2377, 76, -1000, 2785, 182, 238,
	238, 238, -1000, 287, 269, -1000, -1000, 2512, 182, 245,
	11, 434, 3883, 2785, 2094, -1000, -1000, 2785, 341, -1000,
	-1000, -1000, 424, 74, 1349, -1000, 1349, 3760, -1000, 179,
	-1000, -1000, -84, 13, -1000, -1000, -1000, 232, 286, 241,
	3925, -1000, -1000, -28, 446, -1000, 271, -1000, -1000, -6,
	-1000, -1000, -1000, -1000, 14, 665, 783, -1000, 2912, 2912,
	-1000, -1000, 238, 2377, 1945, 74, 340, 2912, 300, 41,
	-1000, 2785, 145, -1000, -1000, -1000, -1000, 316, -1000, -1000,
	375, 3760, 3760, 424, -1000, 74, -1000, 74, 3760, -1000,
	1200, -1000, 216, -1000, 335, -1000, 40, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 133, -1000, 132, 1647, 3883, 438,
	426, 1498, -1000, 2912, 665, 665, -1000, 182, -1000, 182,
	335, -1000, 335, 339, 335, -54, 335, -56, 335, 335,
	335, 335, 335, 335, -1000, 627, -104, -1000, 74, 2785,
	-1000, 316, -1000, 344, -10, -1000, -1000, 178, -1000, -1000,
	3760, -1000, -1000, 394, -1000, 393, 217, 185, -1000, -1000,
	-1000, -1000, -1000, 2785, 2785, -1000, 665, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 2912, 182, 170, 74, 269, 182, 3760,
	3760, -1000, -1000, -1000, -1000, -1000, -1000, 74, 255, 742,
	-1000, -1000, -1000, -1000, -1000, -1000,
}
var yyPgo = [...]int{

	0, 663, 16, 405, 661, 655, 652, 650, 649, 648,
	646, 645, 644, 643, 634, 640, 631, 629, 628, 45,
	623, 13, 51, 7, 36, 8, 622, 31, 54, 47,
	620, 34, 618, 616, 44, 614, 53, 609, 607, 40,
	605, 604, 603, 602, 597, 10, 594, 593, 579, 574,
	573, 25, 1, 4, 28, 9, 572, 490, 27, 568,
	21, 566, 559, 553, 551, 12, 550, 43, 549, 11,
	548, 545, 30, 18, 544, 540, 105, 61, 539, 15,
	0, 20, 35, 26, 538, 647, 22, 41, 537, 531,
	530, 527, 526, 525, 524, 517, 515, 513, 152, 512,
	510, 509, 37, 6, 500, 498, 492, 32, 491, 29,
	489, 487, 486, 14, 5, 485, 2, 484, 33, 483,
	478, 472, 119, 3, 470,
}
var yyR1 = [...]int{

	0, 120, 121, 121, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 2, 2, 3, 3, 4, 4, 5,
	5, 6, 6, 18, 18, 18, 7, 8, 9, 9,
	12, 110, 111, 111, 111, 107, 92, 92, 92, 95,
	95, 93, 93, 93, 93, 93, 93, 94, 94, 94,
	94, 94, 96, 96, 96, 96, 96, 97, 97, 97,
	97, 97, 97, 97, 97, 97, 97, 98, 98, 102,
	102, 103, 103, 103, 100, 100, 101, 101, 104, 104,
	104, 99, 99, 99, 99, 99, 99, 105, 105, 106,
	106, 106, 106, 106, 108, 115, 115, 115, 115, 109,
	109, 117, 117, 116, 112, 112, 112, 113, 113, 113,
	114, 114, 114, 10, 10, 10, 118, 118, 11, 11,
	13, 13, 13, 13, 13, 119, 119, 14, 14, 124,
	15, 16, 16, 17, 17, 19, 19, 23, 23, 22,
	22, 24, 24, 24, 24, 84, 84, 84, 83, 83,
	26, 27, 27, 28, 28, 29, 29, 29, 29, 38,
	71, 71, 30, 30, 30, 31, 31, 32, 32, 89,
	89, 88, 88, 88, 87, 87, 33, 33, 33, 34,
	34, 35, 35, 37, 37, 36, 36, 39, 39, 25,
	25, 25, 25, 25, 25, 25, 75, 75, 41, 41,
	40, 40, 40, 40, 40, 40, 40, 40, 40, 40,
	50, 50, 50, 50, 50, 50, 42, 42, 42, 42,
	42, 42, 42, 21, 21, 51, 51, 51, 57, 52,
	52, 45, 45, 45, 45, 45, 45, 45, 45, 45,
	45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
	45, 45, 45, 45, 45, 45, 45, 48, 48, 48,
	46, 46, 46, 46, 46, 46, 47, 47, 47, 49,
	49, 49, 91, 91, 91, 91, 91, 91, 91, 91,
	91, 91, 91, 91, 91, 91, 91, 91, 91, 61,
	61, 20, 20, 59, 59, 60, 62, 62, 58, 58,
	58, 44, 44, 44, 44, 44, 44, 44, 63, 63,
	64, 64, 65, 65, 66, 66, 67, 68, 68, 68,
	69, 69, 69, 69, 43, 43, 43, 43, 43, 43,
	70, 70, 70, 70, 53, 53, 55, 55, 54, 56,
	72, 72, 73, 76, 76, 77, 77, 74, 74, 78,
	78, 78, 81, 81, 82, 82, 85, 85, 86, 86,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 122, 123, 90,
	90, 90,
}
var yyR2 = [...]int{

	0, 2, 0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 3, 5, 8, 4, 1, 3, 1,
	3, 5, 6, 1, 1, 3, 8, 7, 2, 8,
	4, 4, 1, 3, 3, 6, 3, 1, 1, 2,
	1, 1, 1, 1, 1, 1, 1, 2, 2, 2,
	2, 2, 1, 2, 2, 2, 1, 2, 2, 1,
	1, 1, 1, 1, 1, 1, 1, 0, 3, 0,
	5, 0, 3, 5, 0, 1, 0, 1, 0, 1,
	2, 0, 2, 2, 2, 2, 2, 0, 1, 0,
	2, 1, 2, 1, 4, 2, 3, 2, 2, 1,
	1, 1, 3, 2, 0, 1, 3, 1, 2, 3,
	1, 1, 1, 6, 6, 8, 0, 1, 4, 4,
	4, 5, 3, 3, 5, 0, 1, 2, 2, 0,
	2, 0, 2, 1, 2, 0, 1, 0, 1, 1,
	3, 1, 2, 3, 5, 0, 1, 2, 1, 1,
	2, 1, 3, 1, 1, 1, 1, 3, 3, 2,
	1, 3, 4, 4, 3, 2, 4, 0, 1, 0,
	1, 0, 1, 2, 1, 1, 1, 2, 2, 2,
	3, 2, 2, 2, 1, 1, 3, 0, 2, 1,
	3, 3, 2, 3, 1, 2, 0, 3, 1, 1,
	3, 3, 4, 4, 5, 3, 4, 5, 6, 2,
	1, 2, 1, 2, 1, 2, 1, 1, 1, 1,
	1, 1, 1, 0, 2, 1, 1, 1, 3, 1,
	3, 1, 1, 1, 1, 1, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 1, 1, 1, 1, 4, 5, 6,
	6, 6, 8, 7, 5, 4, 1, 1, 1, 4,
	4, 4, 2, 1, 2, 2, 2, 1, 2, 2,
	1, 2, 2, 2, 2, 2, 2, 2, 1, 0,
	1, 0, 2, 1, 2, 4, 0, 2, 1, 3,
	5, 1, 1, 1, 1, 1, 1, 1, 0, 3,
	0, 2, 0, 3, 1, 3, 2, 0, 1, 1,
	0, 2, 4, 4, 2, 1, 3, 5, 4, 6,
	1, 3, 3, 5, 1, 3, 1, 2, 3, 1,
	1, 3, 3, 0, 2, 0, 3, 0, 1, 0,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 0,
	1, 1,
}
var yyChk = [...]int{

	-1000, -120, -1, -2, -6, -7, -8, -9, -10, -11,
	-13, -14, -3, -4, -18, 8, 9, -12, 93, 94,
	95, 108, 23, 109, 6, -122, 7, 148, 39, -121,
	154, -65, 14, -17, 5, -15, -124, -15, -15, -110,
	39, -78, 98, 103, -81, 42, -80, 117, 136, 130,
	128, 110, 126, 122, 120, 121, 107, 115, 116, 29,
	139, 135, 138, 114, 134, 131, 123, 17, 104, 119,
	141, 113, 132, 124, 125, 137, 112, 133, 142, 153,
	129, 127, 143, 98, 98, 99, 93, 99, 98, -119,
	54, -36, -85, 42, -80, -36, -15, -2, 56, -69,
	16, 15, -5, -3, -122, 18, -74, 101, -16, -27,
	-28, -29, -30, -38, -57, -122, -36, 10, -111, -107,
	42, 99, -77, 102, -36, -76, 102, -76, 98, 10,
	-36, 144, 55, 92, -19, 19, -123, 41, 148, -25,
	-40, 58, -45, 26, 21, -44, -41, -58, -56, -57,
	81, 82, 89, 59, 91, -48, -46, -47, -49, 44,
	43, 45, 46, 47, 48, 51, 52, 53, -81, -85,
	-54, -122, 149, 150, 151, 61, 28, 145, 146, 147,
	102, 87, 148, 42, -80, -66, -67, -25, -65, -2,
	-37, 24, -36, 50, 27, 40, -33, -34, -35, 30,
	33, 35, 31, 36, -89, 20, -27, -2, -122, -88,
	-87, 20, -85, 44, -36, 41, 40, -92, -95, -97,
	-96, -93, -94, 128, 129, 132, 133, 134, 135, 136,
	137, 138, 139, 110, 124, 125, 126, 127, 112, 113,
	114, 115, 116, 117, 119, 120, 121, 122, 123, -77,
	-36, 58, 97, 96, -36, 21, -36, -36, 98, 10,
	-86, -85, -79, 97, 57, 20, 22, 140, 60, 15,
	61, 93, 35, 146, 147, 145, 150, 26, 9, 23,
	109, 19, 85, 95, 64, 65, 111, 21, 53, 10,
	12, 13, 102, 101, 75, 99, 33, 7, 91, 24,
	72, 30, 25, 31, 73, 16, 87, 36, 58, 51,
	37, 56, 14, 34, 74, 96, 148, 32, 6, 152,
	27, 108, 98, 144, 63, 100, 52, 5, 103, 8,
	38, 28, 62, 11, -22, -24, 83, -25, -85, 57,
	56, 72, 40, 17, -25, -42, 75, 58, 73, 74,
	60, 78, 77, 88, 81, 82, 83, 84, 85, 86,
	87, 79, 80, 66, 67, 68, 69, 70, 71, 76,
	-75, -122, -57, -122, -45, -45, -45, -45, -45, -122,
	92, -52, -25, -122, -122, -122, -122, -61, -25, -122,
	-122, -122, -122, 40, -68, 22, 23, -69, -123, -43,
	27, 28, -2, -122, -36, -72, -73, -58, -81, -85,
	-28, -29, -28, -29, 30, 30, 30, 34, 30, -34,
	-85, -123, -123, -2, -87, -39, 11, -112, -113, -114,
	-82, 44, 45, -81, -79, -107, -108, -115, 104, 103,
	-109, 99, 25, -104, 51, 58, -100, 142, -98, 39,
	-98, -98, -98, -98, -98, -102, 39, -102, -102, -103,
	39, -103, 42, 21, -118, 105, 100, -118, -36, -36,
	-26, 40, 10, -84, -83, 20, -81, 44, 92, -25,
	-25, -50, 51, 58, 52, 53, -25, -25, -45, -51,
	-54, -57, 49, 75, 73, 74, 60, -45, -45, -45,
	-45, -45, -45, -45, -45, -45, -45, -45, -45, -45,
	-45, -45, 42, -81, -23, 19, -22, -82, -86, -79,
	40, -123, -25, -58, -19, -59, -60, 62, -58, -22,
	-22, -22, -67, -72, -53, -55, -54, -122, -2, -70,
	-81, -39, 40, 66, 92, -32, -31, 37, 38, -31,
	30, -123, -65, -25, 40, -114, 66, 39, 25, -109,
	42, 42, -99, 26, 51, -101, 143, 45, 45, 45,
	37, -107, -36, -58, -39, -24, -27, -83, 83, -86,
	51, 52, 53, -51, -45, -45, -45, -21, 111, 57,
	-123, -123, -22, -122, 92, -25, 20, 40, -22, -62,
	-60, 64, -25, -123, -123, -123, -123, 40, -123, -123,
	-123, 40, 92, -65, -73, -25, -82, -25, 39, -69,
	-113, -114, -117, -116, -81, 42, -105, 140, 44, 45,
	46, 51, 145, 41, 40, 41, 40, -36, 100, -63,
	12, 92, -21, 57, -45, -45, -123, -23, -82, -91,
	128, 110, 126, 122, 131, 141, 124, 142, 125, 115,
	112, 113, 114, 117, 44, -45, -65, 65, -25, 63,
	-55, 28, -2, -122, -81, -81, -69, -71, -81, 41,
	40, -98, -106, 104, 25, 103, 45, 45, -90, -122,
	-82, -58, -64, 13, 15, 83, -45, -123, -123, -98,
	-98, -103, -98, 116, -98, 116, -98, -98, -98, -98,
	-98, -98, -123, 40, -20, 152, -25, -53, -2, 92,
	40, 41, -116, 25, 25, 41, 41, -25, -52, -45,
	-123, 44, -123, -81, -81, -123,
}
var yyDef = [...]int{

	0, -2, 2, -2, 5, 6, 7, 8, 9, 10,
	11, 12, 312, 0, 129, 129, 129, 0, 349, 0,
	0, 125, 0, 0, 129, 0, 23, 24, 467, 1,
	3, 320, 0, 0, 133, 347, 131, 0, 0, 28,
	0, 0, 345, 350, 351, 352, 353, 431, 432, 433,
	434, 435, 436, 437, 438, 439, 440, 441, 442, 443,
	444, 445, 446, 447, 448, 449, 450, 451, 452, 453,
	454, 455, 456, 457, 458, 459, 460, 461, 462, 463,
	464, 465, 466, 0, 343, 343, 0, 0, 0, 0,
	126, 127, 185, 356, 357, 128, 135, 17, 0, 13,
	0, 0, 312, 19, 0, 134, 0, 348, 130, 0,
	151, 153, 154, 155, -2, 0, 171, 0, 0, 32,
	0, 345, 0, 0, 0, 0, 0, 0, 0, 0,
	122, 123, 0, 0, 0, 136, 18, 468, 25, 321,
	189, 0, 194, 196, 0, 231, 232, 233, 234, 235,
	0, 0, 0, 0, 0, 253, 254, 255, 256, 301,
	302, 303, 304, 305, 306, 307, 198, 199, 298, 0,
	339, 0, 0, 0, 0, 289, 0, 266, 267, 268,
	0, 0, 0, -2, -2, 313, 314, 317, 320, 17,
	0, 0, 184, 132, 0, 0, 0, 0, 0, 176,
	0, 0, 0, 0, 0, 170, 0, 17, 0, 159,
	172, 0, 174, 175, 187, 104, 0, 78, 74, 37,
	38, 67, 40, 67, 67, 59, 60, 61, 62, 63,
	64, 65, 66, 52, 67, 67, 67, 56, 41, 42,
	43, 44, 45, 46, 69, 69, 69, 71, 71, 0,
	30, 0, 116, 116, 118, 344, 119, 120, 0, 0,
	186, 358, 359, 360, 361, 362, 363, 364, 365, 366,
	367, 368, 369, 370, 371, 372, 373, 374, 375, 376,
	377, 378, 379, 380, 381, 382, 383, 384, 385, 386,
	387, 388, 389, 390, 391, 392, 393, 394, 395, 396,
	397, 398, 399, 400, 401, 402, 403, 404, 405, 406,
	407, 408, 409, 410, 411, 412, 413, 414, 415, 416,
	417, 418, 419, 420, 421, 422, 423, 424, 425, 426,
	427, 428, 429, 430, 16, 139, 141, 145, 0, 0,
	0, 0, 0, 0, 192, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 216, 217, 218, 219, 220, 221, 222,
	195, 0, 209, 0, 248, 249, 250, 251, 0, 137,
	0, 0, 229, 0, 0, 0, 135, 0, 290, 0,
	0, 0, 0, 0, 316, 318, 319, 14, 20, 21,
	0, 0, -2, 0, 183, 187, 340, 0, 298, 0,
	152, 167, 0, 164, 177, 178, 179, 0, 181, 182,
	157, 158, 228, 17, 173, 312, 0, 31, 105, 107,
	110, 111, 112, 354, 355, 33, 34, 0, 0, 0,
	0, 99, 100, 81, 79, 0, 76, 75, 39, 0,
	57, 58, 53, 54, 55, 47, 0, 48, 49, 50,
	0, 51, 0, 346, 0, 117, 0, 0, 121, 124,
	187, 0, 0, 142, 146, 0, 148, 149, 0, 190,
	191, 193, 210, 0, 212, 214, 322, 323, 200, 201,
	225, 226, 227, 0, 0, 0, 0, 223, 205, 0,
	236, 237, 238, 239, 240, 241, 242, 243, 244, 245,
	246, 247, 0, 252, 0, 0, 138, 299, 0, -2,
	0, 338, 0, 0, 0, 296, 293, 0, 0, 0,
	0, 0, 315, 22, 324, 334, 336, 0, 17, 0,
	330, 312, 0, 0, 0, 162, 168, 0, 0, 163,
	180, -2, 320, 188, 0, 108, 0, 0, 95, 0,
	97, 98, 87, 0, 80, 36, 77, 0, 0, 0,
	0, 113, 114, 0, 308, 140, 150, 147, 143, 0,
	211, 213, 215, 202, 223, 206, 0, 203, 0, 0,
	197, 257, 0, 137, 0, 230, 0, 0, 312, 0,
	294, 0, 0, 265, 269, 270, 271, 0, 337, -2,
	0, 0, 0, 320, 341, 342, 299, 165, 0, 27,
	106, 109, 0, 101, 67, 96, 89, 88, 82, 83,
	84, 85, 86, 68, 0, 72, 0, 469, 0, 310,
	0, 0, 204, 0, 224, 207, 258, 0, 300, 0,
	67, 273, 67, 71, 67, 277, 67, 280, 67, 67,
	67, 67, 67, 67, 288, 0, 291, 264, 297, 0,
	335, 0, -2, 0, 332, 331, 26, 0, 160, 94,
	0, 103, 35, 0, 91, 93, 0, 0, 29, 470,
	471, 115, 15, 0, 0, 144, 208, 259, 260, 272,
	274, 275, 276, 278, 279, 281, 282, 283, 284, 285,
	286, 287, 261, 0, 0, 0, 295, 327, 17, 0,
	0, 166, 102, 90, 92, 70, 73, 311, 309, 0,
	263, 292, -2, 333, 161, 262,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 59, 3, 3, 3, 86, 78, 3,
	39, 41, 83, 81, 40, 82, 92, 84, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 154,
	67, 66, 68, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 88, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 77, 3, 89,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
	22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
	32, 33, 34, 35, 36, 37, 38, 42, 43, 44,
	45, 46, 47, 48, 49, 50, 51, 52, 53, 54,
	55, 56, 57, 58, 60, 61, 62, 63, 64, 65,
	69, 70, 71, 72, 73, 74, 75, 76, 79, 80,
	85, 87, 90, 91, 93, 94, 95, 96, 97, 98,
	99, 100, 101, 102, 103, 104, 105, 106, 107, 108,
	109, 110, 111, 112, 113, 114, 115, 116, 117, 118,
	119, 120, 121, 122, 123, 124, 125, 126, 127, 128,
	129, 130, 131, 132, 133, 134, 135, 136, 137, 138,
	139, 140, 141, 142, 143, 144, 145, 146, 147, 148,
	149, 150, 151, 152, 153,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:244
		{
			setParseTree(yylex, yyDollar[1].statement)
		}
	case 2:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:249
		{
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:250
		{
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:254
		{
			yyVAL.statement = yyDollar[1].selStmt
		}
	case 13:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:268
		{
			sel := yyDollar[1].selStmt.(*Select)
			sel.OrderBy = yyDollar[2].orderBy
			sel.Limit = yyDollar[3].limit
			yyVAL.selStmt = sel
		}
	case 14:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:275
		{
			yyVAL.selStmt = &Union{Type: yyDollar[2].str, Left: yyDollar[1].selStmt, Right: yyDollar[3].selStmt, OrderBy: yyDollar[4].orderBy, Limit: yyDollar[5].limit}
		}
	case 15:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line sql.y:282
		{
			yyVAL.selStmt = &Select{Comments: Comments(yyDollar[2].bytes2), Distinct: yyDollar[3].str, SelectExprs: yyDollar[4].selectExprs, From: yyDollar[5].tableExprs, Where: NewWhere(WhereStr, yyDollar[6].expr), GroupBy: GroupBy(yyDollar[7].exprs), Having: NewWhere(HavingStr, yyDollar[8].expr)}
		}
	case 16:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:286
		{
			yyVAL.selStmt = &Select{Comments: Comments(yyDollar[2].bytes2), Distinct: yyDollar[3].str, SelectExprs: yyDollar[4].selectExprs}
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:292
		{
			yyVAL.selStmt = yyDollar[1].selStmt
		}
	case 18:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:296
		{
			yyVAL.selStmt = &ParenSelect{Select: yyDollar[2].selStmt}
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:302
		{
			yyVAL.selStmt = yyDollar[1].selStmt
		}
	case 20:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:306
		{
			yyVAL.selStmt = &ParenSelect{Select: yyDollar[2].selStmt}
		}
	case 21:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:313
		{
			// insert_data returns a *Insert pre-filled with Columns & Values
			ins := yyDollar[5].ins
			ins.Action = yyDollar[1].str
			ins.Comments = yyDollar[2].bytes2
			ins.Ignore = yyDollar[3].str
			ins.Table = yyDollar[4].tableName
			yyVAL.statement = ins
		}
	case 22:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:323
		{
			cols := make(Columns, 0, len(yyDollar[6].updateExprs))
			vals := make(ValTuple, 0, len(yyDollar[6].updateExprs))
			for _, updateList := range yyDollar[6].updateExprs {
				cols = append(cols, updateList.Name.Name)
				vals = append(vals, updateList.Expr)
			}
			yyVAL.statement = &Insert{Action: yyDollar[1].str, Comments: Comments(yyDollar[2].bytes2), Ignore: yyDollar[3].str, Table: yyDollar[4].tableName, Columns: cols, Rows: Values{vals}}
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:335
		{
			yyVAL.str = InsertStr
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:339
		{
			yyVAL.str = ReplaceStr
		}
	case 25:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:343
		{
			yyVAL.str = ReplaceStr
		}
	case 26:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line sql.y:349
		{
			yyVAL.statement = &Update{Comments: Comments(yyDollar[2].bytes2), TableExprs: yyDollar[3].tableExprs, Exprs: yyDollar[5].updateExprs, Where: NewWhere(WhereStr, yyDollar[6].expr), OrderBy: yyDollar[7].orderBy, Limit: yyDollar[8].limit}
		}
	case 27:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line sql.y:355
		{
			yyVAL.statement = &Delete{Comments: Comments(yyDollar[2].bytes2), TableExprs: TableExprs{&AliasedTableExpr{Expr: yyDollar[4].tableName}}, Where: NewWhere(WhereStr, yyDollar[5].expr), OrderBy: yyDollar[6].orderBy, Limit: yyDollar[7].limit}
		}
	case 28:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:361
		{
			yyDollar[1].ddl.TableSpec = yyDollar[2].TableSpec
			yyVAL.statement = yyDollar[1].ddl
		}
	case 29:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line sql.y:366
		{
			// Change this to an alter statement
			yyVAL.statement = &DDL{Action: CreateIndexStr, Table: yyDollar[7].tableName, NewName: yyDollar[7].tableName}
		}
	case 30:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:373
		{
			yyVAL.ddl = &DDL{Action: CreateStr, NewName: yyDollar[4].tableName}
			setDDL(yylex, yyVAL.ddl)
		}
	case 31:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:380
		{
			yyVAL.TableSpec = yyDollar[2].TableSpec
			yyVAL.TableSpec.Options = yyDollar[4].str
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:387
		{
			yyVAL.TableSpec = &TableSpec{}
			yyVAL.TableSpec.AddColumn(yyDollar[1].columnDefinition)
		}
	case 33:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:392
		{
			yyVAL.TableSpec.AddColumn(yyDollar[3].columnDefinition)
		}
	case 34:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:396
		{
			yyVAL.TableSpec.AddIndex(yyDollar[3].indexDefinition)
		}
	case 35:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:402
		{
			yyDollar[2].columnType.NotNull = yyDollar[3].boolVal
			yyDollar[2].columnType.Default = yyDollar[4].optVal
			yyDollar[2].columnType.Autoincrement = yyDollar[5].boolVal
			yyDollar[2].columnType.KeyOpt = yyDollar[6].colKeyOpt
			yyVAL.columnDefinition = &ColumnDefinition{Name: NewColIdent(string(yyDollar[1].bytes)), Type: yyDollar[2].columnType}
		}
	case 36:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:411
		{
			yyVAL.columnType = yyDollar[1].columnType
			yyVAL.columnType.Unsigned = yyDollar[2].boolVal
			yyVAL.columnType.Zerofill = yyDollar[3].boolVal
		}
	case 39:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:421
		{
			yyVAL.columnType = yyDollar[1].columnType
			yyVAL.columnType.Length = yyDollar[2].optVal
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:426
		{
			yyVAL.columnType = yyDollar[1].columnType
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:432
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:436
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:440
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:444
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:448
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:452
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 47:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:458
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
			yyVAL.columnType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.columnType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 48:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:464
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
			yyVAL.columnType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.columnType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 49:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:470
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
			yyVAL.columnType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.columnType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 50:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:476
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
			yyVAL.columnType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.columnType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 51:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:482
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
			yyVAL.columnType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.columnType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:490
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 53:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:494
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 54:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:498
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 55:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:502
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:506
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 57:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:512
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 58:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:516
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:520
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:524
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:528
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:532
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:536
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:540
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:544
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:548
		{
			yyVAL.columnType = ColumnType{Type: string(yyDollar[1].bytes)}
		}
	case 67:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:553
		{
			yyVAL.optVal = nil
		}
	case 68:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:557
		{
			yyVAL.optVal = NewIntVal(yyDollar[2].bytes)
		}
	case 69:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:562
		{
			yyVAL.LengthScaleOption = LengthScaleOption{}
		}
	case 70:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:566
		{
			yyVAL.LengthScaleOption = LengthScaleOption{
				Length: NewIntVal(yyDollar[2].bytes),
				Scale:  NewIntVal(yyDollar[4].bytes),
			}
		}
	case 71:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:574
		{
			yyVAL.LengthScaleOption = LengthScaleOption{}
		}
	case 72:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:578
		{
			yyVAL.LengthScaleOption = LengthScaleOption{
				Length: NewIntVal(yyDollar[2].bytes),
			}
		}
	case 73:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:584
		{
			yyVAL.LengthScaleOption = LengthScaleOption{
				Length: NewIntVal(yyDollar[2].bytes),
				Scale:  NewIntVal(yyDollar[4].bytes),
			}
		}
	case 74:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:592
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:596
		{
			yyVAL.boolVal = BoolVal(true)
		}
	case 76:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:601
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:605
		{
			yyVAL.boolVal = BoolVal(true)
		}
	case 78:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:611
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 79:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:615
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 80:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:619
		{
			yyVAL.boolVal = BoolVal(true)
		}
	case 81:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:624
		{
			yyVAL.optVal = nil
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:628
		{
			yyVAL.optVal = NewStrVal(yyDollar[2].bytes)
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:632
		{
			yyVAL.optVal = NewIntVal(yyDollar[2].bytes)
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:636
		{
			yyVAL.optVal = NewFloatVal(yyDollar[2].bytes)
		}
	case 85:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:640
		{
			yyVAL.optVal = NewValArg(yyDollar[2].bytes)
		}
	case 86:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:644
		{
			yyVAL.optVal = NewValArg(yyDollar[2].bytes)
		}
	case 87:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:649
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:653
		{
			yyVAL.boolVal = BoolVal(true)
		}
	case 89:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:658
		{
			yyVAL.colKeyOpt = colKeyNone
		}
	case 90:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:662
		{
			yyVAL.colKeyOpt = colKeyPrimary
		}
	case 91:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:666
		{
			yyVAL.colKeyOpt = colKey
		}
	case 92:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:670
		{
			yyVAL.colKeyOpt = colKeyUniqueKey
		}
	case 93:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:674
		{
			yyVAL.colKeyOpt = colKeyUnique
		}
	case 94:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:680
		{
			yyVAL.indexDefinition = &IndexDefinition{Info: yyDollar[1].indexInfo, Columns: yyDollar[3].indexColumns}
		}
	case 95:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:686
		{
			yyVAL.indexInfo = &IndexInfo{Type: string(yyDollar[1].bytes) + " " + string(yyDollar[2].bytes), Name: NewColIdent("PRIMARY"), Primary: true, Unique: true}
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:690
		{
			yyVAL.indexInfo = &IndexInfo{Type: string(yyDollar[1].bytes) + " " + string(yyDollar[2].str), Name: NewColIdent(string(yyDollar[3].bytes)), Unique: true}
		}
	case 97:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:694
		{
			yyVAL.indexInfo = &IndexInfo{Type: string(yyDollar[1].bytes), Name: NewColIdent(string(yyDollar[2].bytes)), Unique: true}
		}
	case 98:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:698
		{
			yyVAL.indexInfo = &IndexInfo{Type: string(yyDollar[1].str), Name: NewColIdent(string(yyDollar[2].bytes)), Unique: false}
		}
	case 99:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:704
		{
			yyVAL.str = string(yyDollar[1].bytes)
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:708
		{
			yyVAL.str = string(yyDollar[1].bytes)
		}
	case 101:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:714
		{
			yyVAL.indexColumns = []*IndexColumn{yyDollar[1].indexColumn}
		}
	case 102:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:718
		{
			yyVAL.indexColumns = append(yyVAL.indexColumns, yyDollar[3].indexColumn)
		}
	case 103:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:724
		{
			yyVAL.indexColumn = &IndexColumn{Column: yyDollar[1].colIdent, Length: yyDollar[2].optVal}
		}
	case 104:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:729
		{
			yyVAL.str = ""
		}
	case 105:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:733
		{
			yyVAL.str = " " + string(yyDollar[1].str)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:737
		{
			yyVAL.str = string(yyDollar[1].str) + ", " + string(yyDollar[3].str)
		}
	case 107:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:745
		{
			yyVAL.str = yyDollar[1].str
		}
	case 108:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:749
		{
			yyVAL.str = yyDollar[1].str + " " + yyDollar[2].str
		}
	case 109:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:753
		{
			yyVAL.str = yyDollar[1].str + "=" + yyDollar[3].str
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:759
		{
			yyVAL.str = yyDollar[1].colIdent.String()
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:763
		{
			yyVAL.str = "'" + string(yyDollar[1].bytes) + "'"
		}
	case 112:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:767
		{
			yyVAL.str = string(yyDollar[1].bytes)
		}
	case 113:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:773
		{
			yyVAL.statement = &DDL{Action: AlterStr, Table: yyDollar[3].tableName, NewName: yyDollar[3].tableName}
		}
	case 114:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:777
		{
			// Change this to a rename statement
			yyVAL.statement = &DDL{Action: RenameStr, Table: yyDollar[3].tableName, NewName: yyDollar[6].tableName}
		}
	case 115:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line sql.y:782
		{
			// Rename an index can just be an alter
			yyVAL.statement = &DDL{Action: AlterStr, Table: yyDollar[3].tableName, NewName: yyDollar[3].tableName}
		}
	case 116:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:788
		{
		}
	case 118:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:792
		{
			var exists bool
			if yyDollar[3].byt != 0 {
				exists = true
			}
			yyVAL.statement = &DDL{Action: DropStr, Table: yyDollar[4].tableName, IfExists: exists}
		}
	case 119:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:800
		{
			var exists bool
			if yyDollar[3].byt != 0 {
				exists = true
			}
			yyVAL.statement = &DDL{Action: DropIndexStr, Table: yyDollar[4].tableName, IfExists: exists}
		}
	case 120:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:810
		{
			yyVAL.statement = &Show{Type: string(yyDollar[3].bytes), ShowCreate: true, OnTable: yyDollar[4].tableName}
		}
	case 121:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:814
		{
			yyVAL.statement = &Show{Type: string(yyDollar[2].bytes), OnTable: yyDollar[5].tableName}
		}
	case 122:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:818
		{
			yyVAL.statement = &Show{Type: string(yyDollar[2].bytes), OnTable: yyDollar[3].tableName}
		}
	case 123:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:822
		{
			yyVAL.statement = &Show{Type: string(yyDollar[3].bytes)}
		}
	case 124:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:826
		{
			yyVAL.statement = &Show{Type: "table", OnTable: yyDollar[5].tableName}
		}
	case 125:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:831
		{
			yyVAL.bytes = nil
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:835
		{
			yyVAL.bytes = nil
		}
	case 127:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:841
		{
			yyVAL.statement = &Show{Type: "table", OnTable: yyDollar[2].tableName}
		}
	case 128:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:845
		{
			yyVAL.statement = &Show{Type: "table", OnTable: yyDollar[2].tableName}
		}
	case 129:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:850
		{
			setAllowComments(yylex, true)
		}
	case 130:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:854
		{
			yyVAL.bytes2 = yyDollar[2].bytes2
			setAllowComments(yylex, false)
		}
	case 131:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:860
		{
			yyVAL.bytes2 = nil
		}
	case 132:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:864
		{
			yyVAL.bytes2 = append(yyDollar[1].bytes2, yyDollar[2].bytes)
		}
	case 133:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:870
		{
			yyVAL.str = UnionStr
		}
	case 134:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:874
		{
			yyVAL.str = UnionAllStr
		}
	case 135:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:879
		{
			yyVAL.str = ""
		}
	case 136:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:883
		{
			yyVAL.str = DistinctStr
		}
	case 137:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:888
		{
			yyVAL.selectExprs = nil
		}
	case 138:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:892
		{
			yyVAL.selectExprs = yyDollar[1].selectExprs
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:898
		{
			yyVAL.selectExprs = SelectExprs{yyDollar[1].selectExpr}
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:902
		{
			yyVAL.selectExprs = append(yyVAL.selectExprs, yyDollar[3].selectExpr)
		}
	case 141:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:908
		{
			yyVAL.selectExpr = &StarExpr{}
		}
	case 142:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:912
		{
			yyVAL.selectExpr = &AliasedExpr{Expr: yyDollar[1].expr, As: yyDollar[2].colIdent}
		}
	case 143:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:916
		{
			yyVAL.selectExpr = &StarExpr{TableName: TableName{Name: yyDollar[1].tableIdent}}
		}
	case 144:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:920
		{
			yyVAL.selectExpr = &StarExpr{TableName: TableName{Qualifier: yyDollar[1].tableIdent, Name: yyDollar[3].tableIdent}}
		}
	case 145:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:925
		{
			yyVAL.colIdent = ColIdent{}
		}
	case 146:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:929
		{
			yyVAL.colIdent = yyDollar[1].colIdent
		}
	case 147:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:933
		{
			yyVAL.colIdent = yyDollar[2].colIdent
		}
	case 149:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:940
		{
			yyVAL.colIdent = NewColIdent(string(yyDollar[1].bytes))
		}
	case 150:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:946
		{
			yyVAL.tableExprs = yyDollar[2].tableExprs
		}
	case 151:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:952
		{
			yyVAL.tableExprs = TableExprs{yyDollar[1].tableExpr}
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:956
		{
			yyVAL.tableExprs = append(yyVAL.tableExprs, yyDollar[3].tableExpr)
		}
	case 155:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:966
		{
			yyVAL.tableExpr = yyDollar[1].aliasedTableName
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:970
		{
			yyVAL.tableExpr = &AliasedTableExpr{Expr: yyDollar[1].subquery}
		}
	case 157:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:974
		{
			yyVAL.tableExpr = &AliasedTableExpr{Expr: yyDollar[1].subquery, As: yyDollar[3].tableIdent}
		}
	case 158:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:978
		{
			yyVAL.tableExpr = &ParenTableExpr{Exprs: yyDollar[2].tableExprs}
		}
	case 159:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:984
		{
			yyVAL.aliasedTableName = &AliasedTableExpr{Expr: yyDollar[1].tableName, As: yyDollar[2].tableIdent}
		}
	case 160:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:990
		{
			yyVAL.columns = Columns{yyDollar[1].colIdent}
		}
	case 161:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:994
		{
			yyVAL.columns = append(yyVAL.columns, yyDollar[3].colIdent)
		}
	case 162:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1000
		{
			yyVAL.tableExpr = &JoinTableExpr{LeftExpr: yyDollar[1].tableExpr, Join: yyDollar[2].str, RightExpr: yyDollar[3].tableExpr, Condition: yyDollar[4].joinCondition}
		}
	case 163:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1004
		{
			yyVAL.tableExpr = &JoinTableExpr{LeftExpr: yyDollar[1].tableExpr, Join: yyDollar[2].str, RightExpr: yyDollar[3].tableExpr, Condition: yyDollar[4].joinCondition}
		}
	case 164:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1008
		{
			yyVAL.tableExpr = &JoinTableExpr{LeftExpr: yyDollar[1].tableExpr, Join: yyDollar[2].str, RightExpr: yyDollar[3].tableExpr}
		}
	case 165:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1014
		{
			yyVAL.joinCondition = JoinCondition{On: yyDollar[2].expr}
		}
	case 166:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1016
		{
			yyVAL.joinCondition = JoinCondition{Using: yyDollar[3].columns}
		}
	case 167:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1020
		{
			yyVAL.joinCondition = JoinCondition{}
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1022
		{
			yyVAL.joinCondition = yyDollar[1].joinCondition
		}
	case 169:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1025
		{
			yyVAL.empty = struct{}{}
		}
	case 170:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1027
		{
			yyVAL.empty = struct{}{}
		}
	case 171:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1030
		{
			yyVAL.tableIdent = NewTableIdent("")
		}
	case 172:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1034
		{
			yyVAL.tableIdent = yyDollar[1].tableIdent
		}
	case 173:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1038
		{
			yyVAL.tableIdent = yyDollar[2].tableIdent
		}
	case 175:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1045
		{
			yyVAL.tableIdent = NewTableIdent(string(yyDollar[1].bytes))
		}
	case 176:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1051
		{
			yyVAL.str = JoinStr
		}
	case 177:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1055
		{
			yyVAL.str = InnerJoinStr
		}
	case 178:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1059
		{
			yyVAL.str = CrossJoinStr
		}
	case 179:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1065
		{
			yyVAL.str = LeftJoinStr
		}
	case 180:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1069
		{
			yyVAL.str = LeftJoinStr
		}
	case 181:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1075
		{
			yyVAL.str = NaturalJoinStr
		}
	case 182:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1079
		{
			yyVAL.str = NaturalLeftJoinStr
		}
	case 183:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1085
		{
			yyVAL.tableName = yyDollar[2].tableName
		}
	case 184:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1089
		{
			yyVAL.tableName = yyDollar[1].tableName
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1095
		{
			yyVAL.tableName = TableName{Name: yyDollar[1].tableIdent}
		}
	case 186:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1099
		{
			yyVAL.tableName = TableName{Qualifier: yyDollar[1].tableIdent, Name: yyDollar[3].tableIdent}
		}
	case 187:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1104
		{
			yyVAL.expr = nil
		}
	case 188:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1108
		{
			yyVAL.expr = yyDollar[2].expr
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1114
		{
			yyVAL.expr = yyDollar[1].expr
		}
	case 190:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1118
		{
			yyVAL.expr = &AndExpr{Left: yyDollar[1].expr, Right: yyDollar[3].expr}
		}
	case 191:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1122
		{
			yyVAL.expr = &OrExpr{Left: yyDollar[1].expr, Right: yyDollar[3].expr}
		}
	case 192:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1126
		{
			yyVAL.expr = &NotExpr{Expr: yyDollar[2].expr}
		}
	case 193:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1130
		{
			yyVAL.expr = &IsExpr{Operator: yyDollar[3].str, Expr: yyDollar[1].expr}
		}
	case 194:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1134
		{
			yyVAL.expr = yyDollar[1].expr
		}
	case 195:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1138
		{
			yyVAL.expr = &Default{ColName: yyDollar[2].str}
		}
	case 196:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1144
		{
			yyVAL.str = ""
		}
	case 197:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1148
		{
			yyVAL.str = string(yyDollar[2].bytes)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1154
		{
			yyVAL.boolVal = BoolVal(true)
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1158
		{
			yyVAL.boolVal = BoolVal(false)
		}
	case 200:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1164
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: yyDollar[2].str, Right: yyDollar[3].expr}
		}
	case 201:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1168
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: InStr, Right: yyDollar[3].colTuple}
		}
	case 202:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1172
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: NotInStr, Right: yyDollar[4].colTuple}
		}
	case 203:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1176
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: LikeStr, Right: yyDollar[3].expr, Escape: yyDollar[4].expr}
		}
	case 204:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1180
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: NotLikeStr, Right: yyDollar[4].expr, Escape: yyDollar[5].expr}
		}
	case 205:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1184
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: RegexpStr, Right: yyDollar[3].expr}
		}
	case 206:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1188
		{
			yyVAL.expr = &ComparisonExpr{Left: yyDollar[1].expr, Operator: NotRegexpStr, Right: yyDollar[4].expr}
		}
	case 207:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1192
		{
			yyVAL.expr = &RangeCond{Left: yyDollar[1].expr, Operator: BetweenStr, From: yyDollar[3].expr, To: yyDollar[5].expr}
		}
	case 208:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:1196
		{
			yyVAL.expr = &RangeCond{Left: yyDollar[1].expr, Operator: NotBetweenStr, From: yyDollar[4].expr, To: yyDollar[6].expr}
		}
	case 209:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1200
		{
			yyVAL.expr = &ExistsExpr{Subquery: yyDollar[2].subquery}
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1206
		{
			yyVAL.str = IsNullStr
		}
	case 211:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1210
		{
			yyVAL.str = IsNotNullStr
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1214
		{
			yyVAL.str = IsTrueStr
		}
	case 213:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1218
		{
			yyVAL.str = IsNotTrueStr
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1222
		{
			yyVAL.str = IsFalseStr
		}
	case 215:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1226
		{
			yyVAL.str = IsNotFalseStr
		}
	case 216:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1232
		{
			yyVAL.str = EqualStr
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1236
		{
			yyVAL.str = LessThanStr
		}
	case 218:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1240
		{
			yyVAL.str = GreaterThanStr
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1244
		{
			yyVAL.str = LessEqualStr
		}
	case 220:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1248
		{
			yyVAL.str = GreaterEqualStr
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1252
		{
			yyVAL.str = NotEqualStr
		}
	case 222:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1256
		{
			yyVAL.str = NullSafeNotEqualStr
		}
	case 223:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1261
		{
			yyVAL.expr = nil
		}
	case 224:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1265
		{
			yyVAL.expr = yyDollar[2].expr
		}
	case 225:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1271
		{
			yyVAL.colTuple = yyDollar[1].valTuple
		}
	case 226:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1275
		{
			yyVAL.colTuple = yyDollar[1].subquery
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1279
		{
			yyVAL.colTuple = ListArg(yyDollar[1].bytes)
		}
	case 228:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1285
		{
			yyVAL.subquery = &Subquery{yyDollar[2].selStmt}
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1291
		{
			yyVAL.exprs = Exprs{yyDollar[1].expr}
		}
	case 230:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1295
		{
			yyVAL.exprs = append(yyDollar[1].exprs, yyDollar[3].expr)
		}
	case 231:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1301
		{
			yyVAL.expr = yyDollar[1].expr
		}
	case 232:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1305
		{
			yyVAL.expr = yyDollar[1].boolVal
		}
	case 233:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1309
		{
			yyVAL.expr = yyDollar[1].colName
		}
	case 234:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1313
		{
			yyVAL.expr = yyDollar[1].expr
		}
	case 235:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1317
		{
			yyVAL.expr = yyDollar[1].subquery
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1321
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: BitAndStr, Right: yyDollar[3].expr}
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1325
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: BitOrStr, Right: yyDollar[3].expr}
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1329
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: BitXorStr, Right: yyDollar[3].expr}
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1333
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: PlusStr, Right: yyDollar[3].expr}
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1337
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: MinusStr, Right: yyDollar[3].expr}
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1341
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: MultStr, Right: yyDollar[3].expr}
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1345
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: DivStr, Right: yyDollar[3].expr}
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1349
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: IntDivStr, Right: yyDollar[3].expr}
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1353
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: ModStr, Right: yyDollar[3].expr}
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1357
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: ModStr, Right: yyDollar[3].expr}
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1361
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: ShiftLeftStr, Right: yyDollar[3].expr}
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1365
		{
			yyVAL.expr = &BinaryExpr{Left: yyDollar[1].expr, Operator: ShiftRightStr, Right: yyDollar[3].expr}
		}
	case 248:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1369
		{
			if num, ok := yyDollar[2].expr.(*SQLVal); ok && num.Type == IntVal {
				yyVAL.expr = num
			} else {
				yyVAL.expr = &UnaryExpr{Operator: UPlusStr, Expr: yyDollar[2].expr}
			}
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1377
		{
			if num, ok := yyDollar[2].expr.(*SQLVal); ok && num.Type == IntVal {
				// Handle double negative
				if num.Val[0] == '-' {
					num.Val = num.Val[1:]
					yyVAL.expr = num
				} else {
					yyVAL.expr = NewIntVal(append([]byte("-"), num.Val...))
				}
			} else {
				yyVAL.expr = &UnaryExpr{Operator: UMinusStr, Expr: yyDollar[2].expr}
			}
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1391
		{
			yyVAL.expr = &UnaryExpr{Operator: TildaStr, Expr: yyDollar[2].expr}
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1395
		{
			yyVAL.expr = &UnaryExpr{Operator: BangStr, Expr: yyDollar[2].expr}
		}
	case 252:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1399
		{
			// This rule prevents the usage of INTERVAL
			// as a function. If support is needed for that,
			// we'll need to revisit this. The solution
			// will be non-trivial because of grammar conflicts.
			yyVAL.expr = &IntervalExpr{Expr: yyDollar[2].expr, Unit: yyDollar[3].colIdent.String()}
		}
	case 257:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1417
		{
			yyVAL.expr = &FuncExpr{Name: yyDollar[1].colIdent, Exprs: yyDollar[3].selectExprs}
		}
	case 258:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1421
		{
			yyVAL.expr = &FuncExpr{Name: yyDollar[1].colIdent, Distinct: true, Exprs: yyDollar[4].selectExprs}
		}
	case 259:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:1425
		{
			yyVAL.expr = &FuncExpr{Qualifier: yyDollar[1].tableIdent, Name: yyDollar[3].colIdent, Exprs: yyDollar[5].selectExprs}
		}
	case 260:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:1435
		{
			yyVAL.expr = &ConvertExpr{Expr: yyDollar[3].expr, Type: yyDollar[5].convertType}
		}
	case 261:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:1439
		{
			yyVAL.expr = &SubstrExpr{Name: yyDollar[3].colName, From: yyDollar[5].expr, To: nil}
		}
	case 262:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line sql.y:1443
		{
			yyVAL.expr = &SubstrExpr{Name: yyDollar[3].colName, From: yyDollar[5].expr, To: yyDollar[7].expr}
		}
	case 263:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line sql.y:1447
		{
			yyVAL.expr = &GroupConcatExpr{Distinct: yyDollar[3].str, Exprs: yyDollar[4].selectExprs, OrderBy: yyDollar[5].orderBy, Separator: yyDollar[6].str}
		}
	case 264:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1451
		{
			yyVAL.expr = &CaseExpr{Expr: yyDollar[2].expr, Whens: yyDollar[3].whens, Else: yyDollar[4].expr}
		}
	case 265:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1455
		{
			yyVAL.expr = &ValuesFuncExpr{Name: yyDollar[3].colName}
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1465
		{
			yyVAL.expr = &TimeExpr{Expr: NewColIdent("current_timestamp")}
		}
	case 267:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1470
		{
			yyVAL.expr = &TimeExpr{Expr: NewColIdent("current_date")}
		}
	case 268:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1475
		{
			yyVAL.expr = &TimeExpr{Expr: NewColIdent("current_time")}
		}
	case 269:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1485
		{
			yyVAL.expr = &FuncExpr{Name: NewColIdent("if"), Exprs: yyDollar[3].selectExprs}
		}
	case 270:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1489
		{
			yyVAL.expr = &FuncExpr{Name: NewColIdent("mod"), Exprs: yyDollar[3].selectExprs}
		}
	case 271:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1493
		{
			yyVAL.expr = &FuncExpr{Name: NewColIdent("replace"), Exprs: yyDollar[3].selectExprs}
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1499
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1503
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 274:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1507
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 275:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1511
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
			yyVAL.convertType.Length = yyDollar[2].LengthScaleOption.Length
			yyVAL.convertType.Scale = yyDollar[2].LengthScaleOption.Scale
		}
	case 276:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1517
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1521
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 278:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1525
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 279:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1529
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 280:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1533
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 281:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1537
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 282:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1541
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 283:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1545
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 284:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1549
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 285:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1553
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 286:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1557
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 287:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1561
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes), Length: yyDollar[2].optVal}
		}
	case 288:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1565
		{
			yyVAL.convertType = &ConvertType{Type: string(yyDollar[1].bytes)}
		}
	case 289:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1570
		{
			yyVAL.expr = nil
		}
	case 290:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1574
		{
			yyVAL.expr = yyDollar[1].expr
		}
	case 291:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1579
		{
			yyVAL.str = string("")
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1583
		{
			yyVAL.str = " separator '" + string(yyDollar[2].bytes) + "'"
		}
	case 293:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1589
		{
			yyVAL.whens = []*When{yyDollar[1].when}
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1593
		{
			yyVAL.whens = append(yyDollar[1].whens, yyDollar[2].when)
		}
	case 295:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1599
		{
			yyVAL.when = &When{Cond: yyDollar[2].expr, Val: yyDollar[4].expr}
		}
	case 296:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1604
		{
			yyVAL.expr = nil
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1608
		{
			yyVAL.expr = yyDollar[2].expr
		}
	case 298:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1614
		{
			yyVAL.colName = &ColName{Name: yyDollar[1].colIdent}
		}
	case 299:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1618
		{
			yyVAL.colName = &ColName{Qualifier: TableName{Name: yyDollar[1].tableIdent}, Name: yyDollar[3].colIdent}
		}
	case 300:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1622
		{
			yyVAL.colName = &ColName{Qualifier: TableName{Qualifier: yyDollar[1].tableIdent, Name: yyDollar[3].tableIdent}, Name: yyDollar[5].colIdent}
		}
	case 301:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1628
		{
			yyVAL.expr = NewStrVal(yyDollar[1].bytes)
		}
	case 302:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1632
		{
			yyVAL.expr = NewHexVal(yyDollar[1].bytes)
		}
	case 303:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1636
		{
			yyVAL.expr = NewIntVal(yyDollar[1].bytes)
		}
	case 304:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1640
		{
			yyVAL.expr = NewFloatVal(yyDollar[1].bytes)
		}
	case 305:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1644
		{
			yyVAL.expr = NewHexNum(yyDollar[1].bytes)
		}
	case 306:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1648
		{
			yyVAL.expr = NewValArg(yyDollar[1].bytes)
		}
	case 307:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1652
		{
			yyVAL.expr = &NullVal{}
		}
	case 308:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1657
		{
			yyVAL.exprs = nil
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1661
		{
			yyVAL.exprs = yyDollar[3].exprs
		}
	case 310:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1666
		{
			yyVAL.expr = nil
		}
	case 311:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1670
		{
			yyVAL.expr = yyDollar[2].expr
		}
	case 312:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1675
		{
			yyVAL.orderBy = nil
		}
	case 313:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1679
		{
			yyVAL.orderBy = yyDollar[3].orderBy
		}
	case 314:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1685
		{
			yyVAL.orderBy = OrderBy{yyDollar[1].order}
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1689
		{
			yyVAL.orderBy = append(yyDollar[1].orderBy, yyDollar[3].order)
		}
	case 316:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1695
		{
			yyVAL.order = &Order{Expr: yyDollar[1].expr, Direction: yyDollar[2].str}
		}
	case 317:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1700
		{
			yyVAL.str = AscScr
		}
	case 318:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1704
		{
			yyVAL.str = AscScr
		}
	case 319:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1708
		{
			yyVAL.str = DescScr
		}
	case 320:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1713
		{
			yyVAL.limit = nil
		}
	case 321:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1717
		{
			yyVAL.limit = &Limit{Rowcount: yyDollar[2].expr}
		}
	case 322:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1721
		{
			yyVAL.limit = &Limit{Offset: yyDollar[2].expr, Rowcount: yyDollar[4].expr}
		}
	case 323:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1725
		{
			yyVAL.limit = &Limit{Offset: yyDollar[4].expr, Rowcount: yyDollar[2].expr}
		}
	case 324:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1738
		{
			yyVAL.ins = &Insert{Rows: yyDollar[2].values}
		}
	case 325:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1742
		{
			yyVAL.ins = &Insert{Rows: yyDollar[1].selStmt}
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1746
		{
			// Drop the redundant parenthesis.
			yyVAL.ins = &Insert{Rows: yyDollar[2].selStmt}
		}
	case 327:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1751
		{
			yyVAL.ins = &Insert{Columns: yyDollar[2].columns, Rows: yyDollar[5].values}
		}
	case 328:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line sql.y:1755
		{
			yyVAL.ins = &Insert{Columns: yyDollar[2].columns, Rows: yyDollar[4].selStmt}
		}
	case 329:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line sql.y:1759
		{
			// Drop the redundant parenthesis.
			yyVAL.ins = &Insert{Columns: yyDollar[2].columns, Rows: yyDollar[5].selStmt}
		}
	case 330:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1766
		{
			yyVAL.columns = Columns{yyDollar[1].colIdent}
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1770
		{
			yyVAL.columns = Columns{yyDollar[3].colIdent}
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1774
		{
			yyVAL.columns = append(yyVAL.columns, yyDollar[3].colIdent)
		}
	case 333:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line sql.y:1778
		{
			yyVAL.columns = append(yyVAL.columns, yyDollar[5].colIdent)
		}
	case 334:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1784
		{
			yyVAL.values = Values{yyDollar[1].valTuple}
		}
	case 335:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1788
		{
			yyVAL.values = append(yyDollar[1].values, yyDollar[3].valTuple)
		}
	case 336:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1794
		{
			yyVAL.valTuple = yyDollar[1].valTuple
		}
	case 337:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1798
		{
			yyVAL.valTuple = ValTuple{}
		}
	case 338:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1804
		{
			yyVAL.valTuple = ValTuple(yyDollar[2].exprs)
		}
	case 339:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1810
		{
			if len(yyDollar[1].valTuple) == 1 {
				yyVAL.expr = &ParenExpr{yyDollar[1].valTuple[0]}
			} else {
				yyVAL.expr = yyDollar[1].valTuple
			}
		}
	case 340:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1820
		{
			yyVAL.updateExprs = UpdateExprs{yyDollar[1].updateExpr}
		}
	case 341:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1824
		{
			yyVAL.updateExprs = append(yyDollar[1].updateExprs, yyDollar[3].updateExpr)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1830
		{
			yyVAL.updateExpr = &UpdateExpr{Name: yyDollar[1].colName, Expr: yyDollar[3].expr}
		}
	case 343:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1835
		{
			yyVAL.byt = 0
		}
	case 344:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line sql.y:1837
		{
			yyVAL.byt = 1
		}
	case 345:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1840
		{
			yyVAL.empty = struct{}{}
		}
	case 346:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line sql.y:1842
		{
			yyVAL.empty = struct{}{}
		}
	case 347:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1845
		{
			yyVAL.str = ""
		}
	case 348:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1847
		{
			yyVAL.str = IgnoreStr
		}
	case 349:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:1850
		{
			yyVAL.empty = struct{}{}
		}
	case 350:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1852
		{
			yyVAL.empty = struct{}{}
		}
	case 351:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1854
		{
			yyVAL.empty = struct{}{}
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1858
		{
			yyVAL.colIdent = NewColIdent(string(yyDollar[1].bytes))
		}
	case 353:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1862
		{
			yyVAL.colIdent = NewColIdent(string(yyDollar[1].bytes))
		}
	case 355:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1869
		{
			yyVAL.colIdent = NewColIdent(string(yyDollar[1].bytes))
		}
	case 356:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1875
		{
			yyVAL.tableIdent = NewTableIdent(string(yyDollar[1].bytes))
		}
	case 357:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1879
		{
			yyVAL.tableIdent = NewTableIdent(string(yyDollar[1].bytes))
		}
	case 359:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:1886
		{
			yyVAL.tableIdent = NewTableIdent(string(yyDollar[1].bytes))
		}
	case 467:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:2019
		{
			if incNesting(yylex) {
				yylex.Error("max nesting level reached")
				return 1
			}
		}
	case 468:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:2028
		{
			decNesting(yylex)
		}
	case 469:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line sql.y:2033
		{
			forceEOF(yylex)
		}
	case 470:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:2037
		{
			forceEOF(yylex)
		}
	case 471:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line sql.y:2041
		{
			forceEOF(yylex)
		}
	}
	goto yystack /* stack new state and value */
}
